<?php

namespace B2buy\Faqadmin\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use B2buy\Faqadmin\Models\Faq;

class FaqAction
{
    /**
     * Perform the complete action.
     *
     * @param Faq $faq
     *
     * @return Faq
     */
    public function complete(Faq $faq)
    {
        try {
            $faq->status = 'complete';
            return $faq->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Faq $faq
     *
     * @return Faq
     */public function verify(Faq $faq)
    {
        try {
            $faq->status = 'verify';
            return $faq->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Faq $faq
     *
     * @return Faq
     */public function approve(Faq $faq)
    {
        try {
            $faq->status = 'approve';
            return $faq->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Faq $faq
     *
     * @return Faq
     */public function publish(Faq $faq)
    {
        try {
            $faq->status = 'publish';
            return $faq->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Faq $faq
     *
     * @return Faq
     */
    public function archive(Faq $faq)
    {
        try {
            $faq->status = 'archive';
            return $faq->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Faq $faq
     *
     * @return Faq
     */
    public function unpublish(Faq $faq)
    {
        try {
            $faq->status = 'unpublish';
            return $faq->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
